@@ -198,6 +198,7 @@ void parse_args(int argc, char **argv)
 			}
 			break;
 		case 'S':
+			assert(optarg != 0); // optarg can't be NULL (or getopt would choke)
 			fsize_max = strtoul(optarg, &s, 10);
 			fsize_max <<= 20;
 			if (s[0] == ',')
@@ -208,6 +209,7 @@ void parse_args(int argc, char **argv)
 			}
 			break;
 		case 'r':
+			assert(optarg != 0); // optarg can't be NULL (or getopt would choke)
 			/* parse ID:URL */
 			remote_id = strtoul(optarg, &s, 10);
 			if (s[0] == ':')
@@ -233,6 +235,7 @@ void parse_args(int argc, char **argv)
                         }
                         break;
 		case 'C':
+			assert(optarg != 0); // optarg can't be NULL (or getopt would choke)
 			if (!strcmp(optarg, "never"))
 				color_mode = color_never;
 			else if (!strcmp(optarg, "auto"))
@@ -343,13 +346,9 @@ void usage(char *prog)
 	"-d              Delete a module.  Only detached or unused modules\n"
 	"                the user has permission to access will be deleted. Use \"*\"\n"
 	"                (quoted) to delete all unused modules.\n"
-#ifdef HAVE_ELF_GETSHDRSTRNDX
         "-R              Have staprun create a new name for the module before\n"
         "                inserting it. This allows the same module to be inserted\n"
         "                more than once.\n"
-#else
-        "-R              (Module renaming is not available in this configuration.)\n"
-#endif
         "-r N:URI        Pass N:URI data to tapset functions remote_id()/remote_uri().\n"
 	"-D              Run in background. This requires '-o' option.\n"
 	"-S size[,N]     Switches output file to next file when the size\n"
